@@ -1,7 +1,10 @@
 #!/usr/bin/env perl
 
+use strict;
+use warnings;
+
 BEGIN {
-    $ENV{CATALYST_SCRIPT_GEN} = 40;
+    local $ENV{CATALYST_SCRIPT_GEN} = 40;
 }
 
 use Catalyst::ScriptRunner;
